@@ -3,7 +3,6 @@ import fnmatch
 import logging
 import pathlib
 import re
-from collections import OrderedDict
 from collections.abc import Mapping
 from collections.abc import Sequence
 from typing import Any
@@ -154,7 +153,7 @@ class ImmutableDict(Mapping):
         return repr(copy.copy(self))
 
 
-class NamespaceDict(OrderedDict):
+class NamespaceDict(dict):
     """
     A dictionary that can access its string keys through the namespace
     """
@@ -182,9 +181,15 @@ class NamespaceDict(OrderedDict):
         self[k] = v
 
     def __getattr__(self, k: str):
-        if k.startswith("_"):
+        if hasattr(dict, k):
             return super().__getattribute__(k)
-        value = self[k]
+
+        # Swap key errors for attribute errors so that we don't blow up on "hasattr" checks
+        try:
+            value = self[k]
+        except KeyError as e:
+            raise AttributeError(e)
+
         # Allow chain-getting namespaced values
         if isinstance(value, Mapping):
             return NamespaceDict(value)
